==> bfilter_1.0.6.orig.tar.gz: bfilter-1.0.6/main/ServiceContext.h <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef SERVICECONTEXT_H_
#define SERVICECONTEXT_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "FilteringServer.h"
#include "HtmlProcessor.h"
#include "InetAddr.h"

class Reactor;
class ServerTimeouts;

class ServiceContext
{
public:
	ServiceContext(Reactor& reactor);
	
	~ServiceContext();
	
	void reset();
	
	Reactor& reactor() { return m_rReactor; }
	
	Server& server() { return m_server; }
	
	Server& scriptServer() { return m_scriptServer; }
	
	HtmlProcessor& htmlProcessor() { return m_htmlProcessor; }
	
	InetAddr& clientAddr() { return m_clientAddr; }
private:
	static ServerTimeouts getServerTimeouts();
	
	static ServerTimeouts getScriptServerTimeouts();
	
	Reactor& m_rReactor;
	FilteringServer m_server;
	Server m_scriptServer;
	HtmlProcessor m_htmlProcessor;
	InetAddr m_clientAddr;
};

#endif

==> bfilter_1.1.4.orig.tar.gz: bfilter-1.1.4/main/ServiceContext.h <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef SERVICECONTEXT_H_
#define SERVICECONTEXT_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "Server.h"
#include "FilteringServer.h"
#include "CachingServer.h"
#include "HtmlProcessor.h"
#include "InetAddr.h"

class Reactor;
class ServerTimeouts;

class ServiceContext
{
public:
	ServiceContext(Reactor& reactor);
	
	~ServiceContext();
	
	void reset();
	
	Reactor& reactor() { return m_rReactor; }
	
	AbstractServer& server() { return m_filteringServer; }
	
	AbstractServer& scriptServer() { return m_cachingScriptServer; }
	
	HtmlProcessor& htmlProcessor() { return m_htmlProcessor; }
	
	InetAddr& clientAddr() { return m_clientAddr; }
	
	bool isScriptServer(Server const* server) const {
		return server == &m_scriptServer;
	}
private:
	static ServerTimeouts getServerTimeouts();
	
	static ServerTimeouts getScriptServerTimeouts();
	
	Reactor& m_rReactor;
	Server m_server;
	CachingServer m_cachingServer;
	FilteringServer m_filteringServer;
	Server m_scriptServer;
	CachingServer m_cachingScriptServer;
	// m_scriptServer and m_server are separate entities because
	// m_scriptServer needs to fetch scripts while m_server is
	// in the process of fetching the page that references those scripts.
	
	HtmlProcessor m_htmlProcessor;
	InetAddr m_clientAddr;
};

#endif
